SymBlockCipherKey

Struct SymBlockCipherKey 

pub struct SymBlockCipherKey { /* private fields */ }
A symmetric block cipher key.

Associate the raw key material with a symmetric block cipher algorithm identifier.

May get instantiate either through key generation or from an existing raw key via TryFrom.

Implementations

Source

impl SymBlockCipherKey

pub fn get_block_cipher_alg(&self) -> SymBlockCipherAlg

Get the key’s associated symmetric block cipher algorithm identifier.

pub fn take_key(self) -> Zeroizing<Vec<u8>>

Take the key.

pub fn generate( block_cipher_alg: SymBlockCipherAlg, rng: &mut dyn RngCoreDispatchable, additional_rng_generate_input: Option<&[Option<&[u8]>]>, ) -> Result<Self, CryptoError>

Generate a new block cipher key.

Arguments:
  • block_cipher_alg - The block cipher algorithm to generate a key for.
  • rng - The random number generator to obtain key material from.
  • additional_rng_generate_input - Additional input to pass along to the rng’s generate() primitive.
pub fn instantiate_block_cipher_mode_enc( &self, mode: TpmiAlgCipherMode, ) -> Result<SymBlockCipherModeEncryptionInstance, CryptoError>

Instantiate a block cipher mode encryption instance for the key.

Arguments:
  • mode - The block cipher mode to instantiate an encryption instance with the key for.
pub fn instantiate_block_cipher_mode_dec( &self, mode: TpmiAlgCipherMode, ) -> Result<SymBlockCipherModeDecryptionInstance, CryptoError>

Instantiate a block cipher mode decryption instance for the key.

Arguments:
  • mode - The block cipher mode to instantiate an decryption instance with the key for.