pub enum CryptoError {
Show 20 variants
MemoryAllocationFailure = 1,
Internal = 2,
BufferStateIndeterminate = 3,
RngFailure = 4,
InsufficientSeedLength = 5,
RandomSamplingRetriesExceeded = 6,
RequestTooBig = 7,
NoKey = 8,
KeySize = 9,
KeyBinding = 10,
SignatureVerificationFailure = 11,
UnsupportedSecurityStrength = 12,
UnsupportedParams = 13,
UnspecifiedFailure = 14,
InvalidParams = 15,
InvalidIV = 16,
InvalidMessageLength = 17,
InvalidPadding = 18,
InvalidPoint = 19,
InvalidResult = 20,
}Expand description
Common error returned by cryptographic primitives.
Variants
MemoryAllocationFailure = 1
Memory allocation failure.
Internal = 2
Internal logic error.
BufferStateIndeterminate = 3
A source or destination buffer was found in indeterminate state.
To be returned from operand IO slice iterators when encountering a buffer in indeterminate state. Indicates an internal logic error.
RngFailure = 4
Unspecified random number generator failure condition.
InsufficientSeedLength = 5
Attempt to seed a random number generator with a seed of insufficient length.
RandomSamplingRetriesExceeded = 6
Some probabilistic sampling algorithm exceeded the maximum number of retries.
RequestTooBig = 7
Request size is not supported.
NoKey = 8
Private key required for some operation is missing.
KeySize = 9
Key size is not supported by an algorithm.
KeyBinding = 10
Inconsistency between parts of a key.
This most commonly indicates a mismatch between the public and private parts of an asymmetric key pair, but could also get returned for impossible private keys not in the expected domain.
SignatureVerificationFailure = 11
Signature verification failure.
UnsupportedSecurityStrength = 12
Requested security strength is not supported.
UnsupportedParams = 13
Request parameters not supported.
UnspecifiedFailure = 14
Some unspecified failure.
InvalidParams = 15
Invalid parameters.
InvalidIV = 16
Invalid block cipher mode IV length.
InvalidMessageLength = 17
Invalid message length.
InvalidPadding = 18
Invalid padding in message.
InvalidPoint = 19
A point is not in the expected domain.
InvalidResult = 20
A computation resulted in an invalid result.
Implementations
Sourceimpl CryptoError
impl CryptoError
pub fn anonymize_any_sensitive(self, anonymized_value: Self) -> Self
pub fn map(self, from_code: Self, to_code: Self) -> Self